==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fInvokevirtual.h <==
// class soot.coffi.Instruction_Invokevirtual

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b4254de768cda218 soot_coffi_Instruction__5fInvokevirtual
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fInvokevirtual_H_
#define _JC_soot_coffi_Instruction__5fInvokevirtual_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs	_jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs	_jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$refs	_jc_soot_coffi_Instruction__5fInvokevirtual$refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs	_jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$object	_jc_soot_coffi_Instruction__5fInvokevirtual$object;

typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vmethods	_jc_soot_coffi_Instruction__5fInvokevirtual$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtable	_jc_soot_coffi_Instruction__5fInvokevirtual$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtype	_jc_soot_coffi_Instruction__5fInvokevirtual$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fInvokevirtual$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fInvokevirtual$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vmethods	soot_coffi_Instruction__5fInvokevirtual;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$refs {
    _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs	soot_coffi_Instruction__5fInvokevirtual;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs	soot_coffi_Instruction__5fInvokevirtual;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fInvokevirtual$object {
	_jc_soot_coffi_Instruction__5fInvokevirtual$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fInvokevirtual$vtype _jc_soot_coffi_Instruction__5fInvokevirtual$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fInvokevirtual, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fInvokevirtual$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fInvokevirtual_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fInvokevirtual.h <==
// class soot.coffi.Instruction_Invokevirtual

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b4254de768cda218 soot_coffi_Instruction__5fInvokevirtual
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fInvokevirtual_H_
#define _JC_soot_coffi_Instruction__5fInvokevirtual_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs	_jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs	_jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$refs	_jc_soot_coffi_Instruction__5fInvokevirtual$refs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs	_jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fInvokevirtual$object	_jc_soot_coffi_Instruction__5fInvokevirtual$object;

typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vmethods	_jc_soot_coffi_Instruction__5fInvokevirtual$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtable	_jc_soot_coffi_Instruction__5fInvokevirtual$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtype	_jc_soot_coffi_Instruction__5fInvokevirtual$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fInvokevirtual$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fInvokevirtual$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vmethods	soot_coffi_Instruction__5fInvokevirtual;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fInvokevirtual$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$refs {
    _jc_soot_coffi_Instruction__5fInvokevirtual$sub_refs	soot_coffi_Instruction__5fInvokevirtual;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fInvokevirtual$sub_nonrefs	soot_coffi_Instruction__5fInvokevirtual;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fInvokevirtual$object {
	_jc_soot_coffi_Instruction__5fInvokevirtual$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fInvokevirtual$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fInvokevirtual$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fInvokevirtual$vtype _jc_soot_coffi_Instruction__5fInvokevirtual$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fInvokevirtual, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fInvokevirtual$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fInvokevirtual_H_ */
